##  Overview
User Groups are intended to address who is using certain applications. The four major dimensions captured by LeanIX customers are:
  * Regional (e.g. countries or territories)
  * Divisional / Organizational Entities
  * Legal structures
  * User type structures (e.g. blue collar vs. white collar)
